@@ -5,7 +5,9 @@
 pub mod allocation;
 pub mod auth;
 pub mod client;
-pub mod error;
+mod error;
 pub mod proto;
 pub mod relay;
 pub mod server;
+
+pub use error::Error;
